import { __assign, __rest } from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import { randomString } from '../../utils';
import Input from '../Input';
import Textarea from '../Textarea';
import { getJsonDescription } from './utils';
export var operators = {
    contains: {
        getLabel: function (_s) { return 'contains'; },
    },
    not_contains: {
        getLabel: function (_s) { return 'does not contain'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    var value;
    var field;
    if (filter.properties) {
        var keys = Object.keys(filter.properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'contains') {
            value = filter.properties[field].contains.const;
        }
        else {
            return null;
        }
    }
    else if (filter.anyOf) {
        if (filter.anyOf.length === 0 || !filter.anyOf[0].properties) {
            return null;
        }
        var keys = Object.keys(filter.anyOf[0].properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'not_contains') {
            value = filter.anyOf[0].properties[field].not.contains.const;
        }
        else {
            return null;
        }
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: randomString(),
        title: operator,
        description: getJsonDescription(title || field, operators[operator].getLabel(schema), value),
        type: 'object',
    };
    if (operator === 'contains') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'array',
                    contains: {
                        const: value,
                    },
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'not_contains') {
        return assign(base, {
            anyOf: [
                {
                    properties: (_b = {},
                        _b[field] = {
                            type: 'array',
                            not: {
                                contains: {
                                    const: value,
                                },
                            },
                        },
                        _b),
                },
                {
                    properties: (_c = {},
                        _c[field] = {
                            type: 'null',
                        },
                        _c),
                },
            ],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var onUpdate = _a.onUpdate, slim = _a.slim, props = __rest(_a, ["onUpdate", "slim"]);
    if (slim) {
        return (React.createElement(Input, __assign({ onChange: function (e) {
                return onUpdate(e.currentTarget.value);
            } }, props)));
    }
    return (React.createElement(Textarea, __assign({ onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } }, props)));
};
